/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Properties;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * Class to Save GUI Configurations to a Config File
 *
 * @author Meier Philipp
 */
public class Configuration {

    public static Configuration conf;
    private static int x;
    private static int y;
    private static String savelocation = "";
    private static String loadlocation = "";
    private static String location = System.getProperty("user.home")+
            File.separator + "Humigraf.conf";

    private Configuration() {
        loadSettings();
    }

    public static Configuration getInstance() {
        conf = new Configuration();
        return conf;

    }

    public static String getLoadlocation() {
        return loadlocation;
    }

    public static void setLoadlocation(String loadlocation) {
        Configuration.loadlocation = loadlocation;
    }

    public static String getSavelocation() {
        return savelocation;
    }

    public static void setSavelocation(String savelocation) {
        Configuration.savelocation = savelocation;
    }

    public static int getX() {
        return x;
    }

    public static void setX(int x) {
        Configuration.x = x;
    }

    public static int getY() {
        return y;
    }

    public static void setY(int y) {
        Configuration.y = y;
    }

    /**
     * Load Settings every startup.
     */
    private static void loadSettings() {
        Properties settings = new Properties();
        try {
            File file = new File(location);
            if(!file.exists()){
                file.createNewFile();
                saveSettings();
                
            }                    
            settings.load(new FileInputStream(file));
            x = Integer.parseInt(settings.getProperty("x"));
            y = Integer.parseInt(settings.getProperty("y"));
            loadlocation = settings.getProperty("loadLocation");
            savelocation = settings.getProperty("saveLocation");
        } catch (IOException ex) {
            Logger.getLogger(Configuration.class.getName()).log(Level.SEVERE, null, ex);
        }
    }

    /**
     * Save Settings every quit.
     */
    public static void saveSettings() {
        Properties settings = new Properties();
        try {
            settings.setProperty("x", String.valueOf(x));
            settings.setProperty("y", String.valueOf(y));
            settings.setProperty("saveLocation", savelocation);
            settings.setProperty("loadLocation", loadlocation);
            settings.store(new FileOutputStream(location), null);
        } catch (IOException ex) {
            Logger.getLogger(Configuration.class.getName()).log(Level.SEVERE, null, ex);
        }
    }
}
