/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf;

import ch.praeber.humigraf.system.Controller;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ResourceBundle;
import javax.swing.*;
import javax.swing.border.Border;

/**
 * Import Dialog
 * Import Data form Humigraf
 * @author Meier Philipp
 */

//TODO change intervall type
public class ImportDialog extends JDialog {
    private static final ResourceBundle languages = 
            ResourceBundle.getBundle("ch/praeber/humigraf/resources/languages/Languages");

    //Information Panel
    private JPanel informationpanel;
    private Border informationborder;
    private JLabel lblwarning;
    //Configuration Panel
    private JPanel configurationpanel;
    private Border configurationborder;
    private JComboBox deviceName;
    private JCheckBox removeData;
    private JLabel DeviceLabel;
    //Buttons
    private JButton CancelButton;
    private JButton ImportButton;
    private JPanel ButtonPanel;
    private Controller controller;
    private AnalyticsGUI parent;

    /**
     * UI to configure Import Thread
     * @param parent AnayliticsGUI set if Live Tracking has been configured
     * @param control Controls the acctual import into the dataset
     */
    public ImportDialog(AnalyticsGUI parent, Controller control) {
        super(parent);
        this.parent = parent;
        setTitle(languages.getString("IMPORT DATA"));
        controller = control;
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setSize(400, 250);
        setMinimumSize(getSize());
        BorderLayout lyt = new BorderLayout();
        setLayout(lyt);
        initialise();
        setupListeners();
        //  setResizable(false);
        setModal(true);
        setLocationRelativeTo(this.parent);
        setVisible(true);
    }

    /**
     * Initialises Buttons, Panels and constructs the Window
     */
    private void initialise() {

        //Greate Button Space
        CancelButton = new JButton(languages.getString("CANCEL"));
        ImportButton = new JButton(languages.getString("IMPORT DATA"));
        ButtonPanel = new JPanel();
        ButtonPanel.setLayout(new FlowLayout(FlowLayout.TRAILING));
        ButtonPanel.add(ImportButton);
        ButtonPanel.add(CancelButton);

        //informationpanel
        lblwarning = new JLabel(languages.getString("<HTML>IMPORTING DATA FROM DEVICE WILL TAKE SOME")
                + languages.getString(" TIME. PLEASE DO NOT UNPLUG YOUR P-RAEBER HUMIGRAF UNTIL THE ")
                + languages.getString("IMPORT HAS FINISHED.</HTML>"));
        informationpanel = new JPanel();
        informationpanel.setLayout(new GridLayout(1, 1));
        informationborder = BorderFactory.createTitledBorder(languages.getString("INFORMATION"));
        informationpanel.setBorder(informationborder);
        informationpanel.add(lblwarning);


        //configurationpanel
        configurationpanel = new JPanel();
        configurationpanel.setLayout(new FlowLayout(FlowLayout.LEFT));
        configurationborder = BorderFactory.createTitledBorder(languages.getString("CONFIGURATION"));
        configurationpanel.setBorder(configurationborder);

        deviceName = new JComboBox();
        deviceName.setModel(new javax.swing.DefaultComboBoxModel());
        deviceName.addItem(languages.getString("NO DEVICE FOUND"));
        deviceName.setEditable(false);
        removeData = new JCheckBox(languages.getString("<HTML>REMOVE RECORDS FROM HUMIGRAF AFTER IMPORT?</HTML>"));
        DeviceLabel = new JLabel(languages.getString("<HTML>P-RAEBER DEVICE:</HTML>"));


        //configurationpanel.add(DeviceLabel);
        //configurationpanel.add(deviceName);
        configurationpanel.add(removeData);


        //Add the Components to the Window
        add(informationpanel, BorderLayout.NORTH);
        add(configurationpanel, BorderLayout.CENTER);
        add(ButtonPanel, BorderLayout.SOUTH);
    }

    /**
     * Sets up the Listeners to all Menu Points
     */
    private void setupListeners() {
        //ImportButton Listener
        ImportButton.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                importData();
            }
        });


        //Cancel_Button Listener
        CancelButton.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                cancelAction();
            }
        });



    }

    /**
     * Stops the theard but leaves the loaded data in.
     */
    private void cancelAction() {
        setVisible(false);
        this.removeAll();
    }

    /**
     * Starts an Import
     */
    private void importData() {
        int device = 0;
        //start Dialog
        setVisible(false);
        //removeAll();
        //ProgressMonitor
        ProgressMonitor prgMon = new ProgressMonitor(parent,
                languages.getString("DO NOT UNPLUG HUMIGRAF.") + "\n" + languages.getString("PLEASE WAIT"), languages.getString("PLEASE DO NOT ")
                + languages.getString("UNPLUG HUMIGRAF WHILE PROCESSING!"), 0, 100);
        //Start Process
        boolean answ = controller.importData(device, prgMon, removeData.isSelected());
    }
}
