/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf;

import java.io.File;
import java.util.ResourceBundle;
import javax.swing.filechooser.*;

/**
 * Implements a FileFilter for P-Raeber Analytics
 * @author Meier Philipp
 */

public class RaeberFileFilter extends FileFilter {

    private String FileExtension;
    private String Description = null;
    public static final String P_RAEBER_EXT="humigraf";
    private static final String PNG_EXT="png";
    private static final String CSV_EXT="csv";
    private static final ResourceBundle languages = 
            ResourceBundle.getBundle("ch/praeber/humigraf/resources/languages/Languages");

    RaeberFileFilter(String fileExtension) {
        FileExtension = fileExtension;
        if(FileExtension.contentEquals(P_RAEBER_EXT)){
            Description = languages.getString("P-RAEBER HUMIGRAF FILES (.HUMIGRAF)");
        }else if(FileExtension.contentEquals(PNG_EXT)){
            Description = languages.getString("EXPORT TO PNG (.PNG)");
        }else if(FileExtension.contentEquals(CSV_EXT)){
            Description = languages.getString("EXPORT TO CSV (.CSV)");
        }


    }

    //Accept all directories and only Raeber files.
    /**
     *  Checks if a certain file shall be accepted by JFileChooser
     * @param pathname Name of the Path used by JFileChooser
     * @return true if directories or only Raeber files
     */
    @Override
    public boolean accept(File pathname) {
        if (pathname.isDirectory()) {
            return true;
        }

        //Gets the File extension (Ugly to work with File extensions
        String extension = null;
        String s = pathname.getName();
        int i = s.lastIndexOf('.');
        if (i > 0 && i < s.length() - 1) {
            extension = s.substring(i + 1).toLowerCase();
        }

        //Compares the Extension with the acctual file
        if (extension != null) {
            if (extension.equals(FileExtension)) {
                return true;
            } else {
                return false;
            }
        }

        return false;
    }

    //The description of this filter
    @Override
    public String getDescription() {
        return Description;
    }

    /**
     *
     * @return the FileExtension to be used with FileChooser
     */
    public String getExtension(){
        return FileExtension;
    }

    @Override
    public String toString(){
        return getExtension();
    }

}
