/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf;

import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.GregorianCalendar;
import java.util.ResourceBundle;
import org.jfree.chart.labels.XYToolTipGenerator;
import org.jfree.data.xy.XYDataset;
import ch.praeber.humigraf.system.Fahrenheit;
import java.text.DecimalFormat;

/**
 * ToolTip for RChart
 * @author Meier Philipp
 */
public class ToolTipGenerator implements XYToolTipGenerator {

    private static final ResourceBundle languages = ResourceBundle.getBundle("ch/praeber/humigraf/resources/languages/Languages");
    private String label = "";
    private static final String TEMPERATURE = languages.getString("TEMPERATURE");
    private String TEMPERATURE_LABEL;
    private static final String HUMIDITY = languages.getString("HUMIDITY");
    private static final String HUMIDITY_LABEL = "%";
    private Date date;
    private GregorianCalendar cal;
    private DateFormat formatter;
    private DecimalFormat df = new DecimalFormat("0.0");

    public ToolTipGenerator(String DataName) {
        //stupid idea, other way to identify dataset
        label = DataName;
    }

    @Override
    public String generateToolTip(XYDataset dataset, int series, int item) {
        // throw new UnsupportedOperationException("Not supported yet.");

        double datevalue = dataset.getXValue(series, item);
        double Value = dataset.getYValue(series, item);
        TEMPERATURE_LABEL = Fahrenheit.getSIUnit();
        formatter = new SimpleDateFormat();
        date = new Date((long) datevalue);
        cal = new GregorianCalendar();
        cal.setTime(date);

        String finaldate = formatter.format(cal.getTime());        
//Stupid
        if (label.matches(TEMPERATURE) && series != 3) {
            return label + ": " + df.format(Value) + " " + TEMPERATURE_LABEL +
                    languages.getString(" DATE: ") + " " + finaldate 
                    + " " + "Nr. " + item;

        } else if (label.matches(TEMPERATURE) && series == 3) {
            return languages.getString("DEW POINT") + ": " + df.format(Value) 
                    + " " + TEMPERATURE_LABEL + languages.getString(" DATE: ") 
                    + " " + finaldate + " " + "Nr. " + item;
        } else {
            return label + ": " + df.format(Value) + " " + HUMIDITY_LABEL
                    + languages.getString(" DATE: ") + " " + finaldate 
                    + " " + "Nr. " + item;
        }
    }
}
