/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf;

import ch.praeber.humigraf.system.Controller;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.ResourceBundle;
import javax.swing.*;
import javax.swing.border.Border;

/**
 * Tracking Dialog
 * @author Meier Philipp
 */
public class TrackingDialog extends JDialog {
    private static final ResourceBundle languages = 
            ResourceBundle.getBundle("ch/praeber/humigraf/resources/languages/Languages");
    //information panel

    private JLabel Description;
    private JPanel informationpanel;
    private Border informationborder;
    //configurationpanel
    private JPanel configurationpanel;
    private JLabel IntervallLabel;
    private JComboBox IntervallCombo;
    private JLabel DeviceLabel;
    private JComboBox deviceName;
    private Border configurationborder;
    //Buttons
    private JButton CancelButton;
    private JButton StartButton;
    private JPanel ButtonPanel;
    private Controller control;
    private AnalyticsGUI parent;

    /**
     * Tracking Dialog.
     * @param parent Parent Window
     * @param control Controller
     */
    public TrackingDialog(AnalyticsGUI parent, Controller control) {
        super(parent);
        this.control = control;
        this.parent = parent;
        setTitle(languages.getString("START LIVE TRACKING"));
        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        setModal(true);
        setSize(380, 200);
        setMinimumSize(getSize());
        setLayout(new BorderLayout());
        initialise();
        setupListeners();
        //  setResizable(false);
        if (control.isThreadActive()) {
            IntervallCombo.setEnabled(false);
            IntervallCombo.removeAllItems();
            IntervallCombo.addItem(control.getInterval() + languages.getString(" MIN"));
            deviceName.setEnabled(false);
        }
        setLocationRelativeTo(this.parent);
        setVisible(true);

    }

    /**
     * Initialises Buttons, Panels and constructs the Window
     */
    private void initialise() {
        //Greate Button Space
        CancelButton = new JButton(languages.getString("CANCEL"));
        if (control.isThreadActive()) {
            StartButton = new JButton(languages.getString("STOP TRACKING"));
        } else {
            StartButton = new JButton(languages.getString("START TRACKING"));
        }
        ButtonPanel = new JPanel();
        ButtonPanel.setLayout(new FlowLayout(FlowLayout.TRAILING));
        ButtonPanel.add(StartButton);
        ButtonPanel.add(CancelButton);

        //informationpanel
        GridLayout glay = new GridLayout();
        informationpanel = new JPanel(glay);
        informationborder = BorderFactory.createTitledBorder(languages.getString("INFORMATION"));
        informationpanel.setBorder(informationborder);

        //configurationpanel        
        configurationpanel = new JPanel(new FlowLayout(FlowLayout.LEFT));
        configurationborder = BorderFactory.createTitledBorder(languages.getString("CONFIGURATION"));
        configurationpanel.setBorder(configurationborder);


        //Setting up Combobox for Intervall
        Description = new JLabel(languages.getString("<HTML>RECORD TEMPERATURE AND HUMIDITY DIRECTLY")
                + languages.getString(" TO YOUR COMPUTER. CHOOSE AN APPROPRIATE INTERVAL.</HTML>"));
        IntervallLabel = new JLabel(languages.getString("<HTML>LIVE TRACKING")
                + languages.getString(" TIME INTERVAL:</HTML>"));
        IntervallCombo = new JComboBox();
        IntervallCombo.setModel(new javax.swing.DefaultComboBoxModel());
        IntervallCombo.addItem("1 Min");
        IntervallCombo.addItem("5 Min");
        IntervallCombo.addItem("10 Min");
        IntervallCombo.addItem("15 Min");
        IntervallCombo.addItem("30 Min");
        IntervallCombo.addItem("60 Min");
        IntervallCombo.setEditable(false);


        //Setting up Combobox for Device
        DeviceLabel = new JLabel(languages.getString("<HTML><B>P-RAEBER DEVICE:</HTML>"));
        deviceName = new JComboBox();
        deviceName.setModel(new javax.swing.DefaultComboBoxModel());
        deviceName.addItem(languages.getString("NO DEVICE FOUND"));
        deviceName.setEditable(false);

        //Setting Default
        informationpanel.add(Description);
        // configurationpanel.add(DeviceLabel);
        // configurationpanel.add(deviceName);
        configurationpanel.add(IntervallLabel);
        configurationpanel.add(IntervallCombo);


        //Add the Components to the Window
        add(informationpanel, BorderLayout.NORTH);
        add(configurationpanel, BorderLayout.CENTER);
        add(ButtonPanel, BorderLayout.SOUTH);
    }

    /**
     * Setup all Listeners
     */
    private void setupListeners() {
        //Cancel_Button Listener
        StartButton.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                TrackingAction();
            }
        });
        //Cancel_Button Listener
        CancelButton.addActionListener(new ActionListener() {

            @Override
            public void actionPerformed(ActionEvent e) {
                cancelAction();
            }
        });
    }

    /**
     * CancelButton Action
     */
    private void cancelAction() {
        //Clear all necessery data from the devices etc
        //control.stopThread();
        setVisible(false);
        this.removeAll();

    }

    /**
     * Starts the Tracking Action
     */
    private void TrackingAction() {
        if (control.isThreadActive()) {
            control.stopThread();
            parent.setLiveTracking(false);
            //parent.setAbilityToSave(true);
        } else {
            String s = (String) IntervallCombo.getSelectedItem();
            String[] a = s.split(" ");
            control.startLiveTracking(0, Integer.valueOf(a[0]));
            parent.setLiveTracking(true);
            control.startThread();
        }

        setVisible(false);
    }
}
