/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf.model;

import java.io.Serializable;
import java.util.Date;

/**
 * DataEntry
 * Single data entity to store informations of humidity and temperature
 * @author Meier Philipp
 */
public class DataEntry implements Serializable {

    private double temp;
    private double hum;
    private double tau;
    private Date date;

    /**
     * Create a Entity
     * @param temp
     * @param hum
     * @param date
     */
    public DataEntry(double temp, double hum, long date) {
        this.temp = temp;
        this.hum = hum;
        this.date = new Date(date);
        tau = setTau(temp, hum);
    }

    /**
     * Calcualte the tau point for a certain time
     * @param t Temperature
     * @param h Humidity
     * @return Tau Value
     */
    private double setTau(double t, double h) {
        double ew = Math.pow(10, 0.66077+(7.5*t/ (237.3+t)));
        double ew_rh = (ew * h) / 100;
        double dp =((0.66077-Math.log10(ew_rh))*237.3) / (Math.log10(ew_rh)-8.16077);
        return dp;
    }

    /**
     * Return the Temperature.
     * @return Temperature
     */
    public double getTemp() {
        return temp;
    }

    /**
     * Return Himidity
     * @return Humidity
     */
    public double getHum() {
        return hum;
    }

    /**
     * Time when the values where captured
     * @return Date
     */
    public Date getDate() {
        return date;
    }

    /**
     * Get Tau Value
     * @return Tau Value
     */
    public double getTau() {
        return tau;
    }
}
