/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf.system;

/**
 *
 * @author Meier Philipp <philipp.meier@stud.hslu.ch> *
 */
public class DeviceControl implements iControl {

    // <editor-fold desc="NATIVE METHODS">
    /**
     * @inheritdoc
     */
    @Override
    public native int setInterval(int Intervall,
            int device);

    /**
     * @inheritdoc
     */
    @Override
    public native int getInterval(
            int device);

    /**
     * @inheritdoc
     */
    @Override
    public native double[] getAcctualValues(int deviceNumber);

    /**
     * @inheritdoc
     */
    @Override
    public native double[] readMemory(int device);

    /**
     * @inheritdoc
     */
    @Override
    public native int deleteMemory(int device);

    /**
     * Returns a String with all Raeber Devices currently attached to the System
     *
     * @return A String with all Raeber Devices, seperated by #
     */
    private native String getReaberDevices();

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int getMemorySize();

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int requestMemoryDump();

    /**
     *
     * @inheritdoc
     */
    @Override
    public native double[] getDataPackage();

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int getPaperFeed(int device);

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int setPaperFeed(int device, int paperfeed);

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int setTemperatureUnit(int device, int unit);

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int getTemperatureUnit(int device);

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int setAlarm(int device, int alarm);

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int getAlarm(int device);

    /**
     *
     * @inheritdoc
     */
    @Override
    public native int abort(int device);

    /**
     * @inheritdoc
     */
    private native int getNativeMinTemp(int device);

    private native int setNativeMinTemp(int device, int temperature_enumartion);

    private native int getNativeMaxTemp(int device);

    private native int setNativeMaxTemp(int device, int temperature_enumartion);

    /**
     * @inheritdoc
     */
    @Override
    public native int getMinHum(int device);

    /**
     * @inheritdoc
     */
    @Override
    public native int setMinHum(int device, int humidity);

    /**
     * @inheritdoc
     */
    @Override
    public native int getMaxHum(int device);

    /**
     * @inheritdoc
     */
    @Override
    public native int setMaxHum(int device, int humidity);

    /**
     * @inheritdoc
     */
    @Override
    public int getMinTemp(int device) {
        int answer = 0;
        answer = this.getNativeMinTemp(device);
        if (getTemperatureUnit(device) == 0) {
            answer = answer * 2 + 20;
        } else {
            answer = answer - 5;
        }
        return answer;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setMinTemp(int device, int temperature) {
        int answer = 0;
        if (getTemperatureUnit(device) == 0) {
            temperature = (temperature - 20) / 2;
        } else {
            temperature = temperature + 5;
        }
        answer = this.setNativeMinTemp(device, temperature);
        return answer;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getMaxTemp(int device) {
        int answer = 0;
        answer = this.getNativeMaxTemp(device);
        if (getTemperatureUnit(device) == 0) {
            answer = answer * 2 + 20;
        } else {
            answer = answer - 5;
        }
        return answer;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setMaxTemp(int device, int temperature) {
        int answer = 0;
        if (getTemperatureUnit(device) == 0) {
            temperature = (temperature - 20) / 2;
        } else {
            temperature = temperature + 5;
        }
        answer = this.setNativeMaxTemp(device, temperature);
        return answer;
    }

    /**
     * @inheritdoc
     */
    @Override
    public native int getBatteryState(int device);
    /**
     * @inheritdoc
     */
    @Override
    public native int getDeviceSector(int device);

// </editor-fold>
    /**
     * @inheritdoc
     */
    @Override
    public String[] getDevices() {
        String dev = getReaberDevices();
        if (dev.equals("No Device Found!")) {
            return null;
        } else {
            String[] end = dev.split("#");
            return end;
        }
    }

    static {
        //Loads  "DeviceControl.dll" (Windows)or "libDeviceControl.so" (Linux)
        if (System.getProperty("os.name").equals("Linux")) {
            System.loadLibrary("DeviceControl");
        } else {
            //For windows
            System.loadLibrary("setupapi");
            System.loadLibrary("kernel32");
            System.loadLibrary("msvcr100");
            System.loadLibrary("hidapi");
            System.loadLibrary("DeviceControl");

        }
    }
}
