/*
 * Copyright (C) Paul Räber 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf.system;

import ch.praeber.humigraf.model.DataList;
import ch.praeber.humigraf.model.DataManager;
import ch.praeber.humigraf.model.DataEntry;
import au.com.bytecode.opencsv.CSVWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.Locale;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * ExportCSV
 * Version 1.0.0
 * Class to export data to csv
 * @author Meier Philipp <philipp.meier@stud.hslu.ch>
 */
public class ExportCSV {

    private File file;
    private DataManager datamanager;
    private String temp = "Temperature";
    private String hum = "Humidity %";
    private String dew = "Dew Point";
    private String date = "Date";
    private String[] topline;
    private Locale locale;
    private DateFormat formatter;

    public ExportCSV(DataManager manager) {
        datamanager = manager;
        topline = new String[4];
        topline[0] = date;
        topline[1] = Fahrenheit.addSIUnit(temp);
        topline[2] = hum;
        topline[3] = Fahrenheit.addSIUnit(dew);
        formatter = new SimpleDateFormat();
        locale = Locale.getDefault();
    }

    /**
     * Export to CSV
     * @param f file to export to
     * @return true if it works
     */
    public boolean exportCSV(File f) {
        //Initialising CSVWriter & setting up File Stream
        CSVWriter writer;
        try {
            FileWriter filewriter = new FileWriter(f);

            writer = new CSVWriter(filewriter);

            writer.writeNext(topline);
            writer.flush();
            //Ugly but neccessary to write a line diffrently
            writer = new CSVWriter(filewriter, CSVWriter.DEFAULT_SEPARATOR,
                    CSVWriter.NO_QUOTE_CHARACTER);

            String line[] = new String[4];
            DataList list = datamanager.getList();
            

            if (locale.equals(Locale.US)) {
                for (DataEntry a : list) {
                    line[0] = formatter.format(a.getDate());
                    line[1] = String.valueOf(Fahrenheit.toFahrenheit(a.getTemp()));
                    line[2] = String.valueOf(a.getHum());
                    line[3] = String.valueOf(Fahrenheit.toFahrenheit(a.getTau()));
                    writer.writeNext(line);
                    writer.flush();
                }
            } else {
                for (DataEntry a : list) {
                    line[0] = formatter.format(a.getDate());
                    line[1] = String.valueOf(a.getTemp());
                    line[2] = String.valueOf(a.getHum());
                    line[3] = String.valueOf(a.getTau());
                    writer.writeNext(line);
                    writer.flush();
                }

            }
            writer.flush();
            writer.close();

        } catch (IOException ex) {
            Logger.getLogger(ExportCSV.class.getName()).log(Level.SEVERE, null, ex);
            return false;
        }
        return true;

    }
}
