/*
 * Copyright (C) Paul Räber 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf.system;

import java.util.Random;

/**
 * Simulation class to sim the humigraf for Debuging purposes only.
 *
 * @author phil
 */
public class HumigrafSimulator implements iControl {

    private double[] data;
    private int intervall = 2;
    private double[] pass;
    private int counter = 0;
    private int minhum = 3;
    private int maxhum = 99;
    private int mintemp = 10;
    private int maxtemp = 40;
    private int alarm = 0;
    private int siunit = 1;
    private int paperfeed = 0;

    public HumigrafSimulator() {
        data = generateValues();
    }

    private double[] generateValues() {
        double[] array = new double[320];
        for (int i = 0; (i + 1) < array.length; i++) {
            array[i] = Math.floor((Math.random() * 49) + 1);
            array[i + 1] = Math.floor((Math.random() * 50));
        }
        return array;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setInterval(int Intervall, int device) {
        //Check if correct intervall
        data = generateValues(); //reset values
        intervall = Intervall;
        return 0;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getInterval(int device) {
        return intervall;
    }

    /**
     * @inheritdoc
     */
    @Override
    public double[] getAcctualValues(int deviceNumber) {
        Random temprand = new Random();
        Random humrand = new Random();
        double hum = 60 + humrand.nextDouble();
        double temp = 20;
        double[] result = new double[2];
        result[0] = hum;
        result[1] = temp;
        return result;
    }

    /**
     * @inheritdoc
     */
    @Override
    public double[] readMemory(int device) {
        return data;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getMemorySize() {
        return data.length;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int deleteMemory(int device) {
        data = null;
        return 0;
    }

    /**
     * @inheritdoc
     */
    @Override
    public String[] getDevices() {
        throw new UnsupportedOperationException("Not supported yet.");
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int requestMemoryDump() {
        return 0;
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public double[] getDataPackage() {
        pass = new double[32];
        int z = 0;
        for (int i = counter; i < (counter + 32); i++) {
            pass[z] = data[i];
            z++;
        }
        counter += 32;
        return pass;
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int setPaperFeed(int device, int paperfeed) {
        if (paperfeed >= 0 && paperfeed <= 3) {
            this.paperfeed = paperfeed;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int getPaperFeed(int device) {
        return paperfeed;
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int setTemperatureUnit(int device, int unit) {
        if (unit >= 0 && unit <= 1) {
            siunit = unit;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int getTemperatureUnit(int device) {
        return siunit;
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int setAlarm(int device, int alarm) {
        if (alarm >= 0 && alarm <= 10) {
            this.alarm = alarm;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int getAlarm(int device) {
        return alarm;
    }

    /**
     *
     * @inheritdoc
     */
    @Override
    public int abort(int device) {
        //reset counter
        return 0;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getMinTemp(int device) {
        return mintemp;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setMinTemp(int device, int temperature) {
        if (temperature >= -5 && temperature <= 45) {
            mintemp = temperature;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getMaxTemp(int device) {
        return maxtemp;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setMaxTemp(int device, int temperature) {
        if (temperature >= -5 && temperature <= 45) {
            maxtemp = temperature;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getMinHum(int device) {
        return minhum;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setMinHum(int device, int humidity) {
        if (humidity >= 0 && humidity <= 100) {
            minhum = humidity;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getMaxHum(int device) {
        return maxhum;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int setMaxHum(int device, int humidity) {
        if (humidity >= 0 && humidity <= 100) {
            maxhum = humidity;
            return 0;
        } else {
            return -1;
        }
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getBatteryState(int device) {
        return 1;
    }

    /**
     * @inheritdoc
     */
    @Override
    public int getDeviceSector(int device) {
        return 1;
    }
}
