/*
 * Copyright (C) Philipp Meier 2011
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package ch.praeber.humigraf.system;

import java.util.Date;

/**
 * LiveTrackingThread
 * Version 1.0.0
 * Thread which trackes data live
 * @author Meier Philipp <meier.phi@gmail.com>
 *
 */
public class LiveTrackingThread implements Runnable {

    private Controller control;
    private long millis;
    private int device;

    public LiveTrackingThread(int device, long millis, Controller control) {
        this.control = control;
        this.millis = millis;
        this.device = device;
    }

    @Override
    public void run() {
        while (control.isThreadActive()) {
            try {
                //get Values
                double data[] = control.getActualValues(device);
                double hum = data[0];
                double temp = data[1];
                control.addLiveEntry(temp, hum, new Date());
                control.setSaved(false);
                Thread.sleep(millis);
            } catch (NullPointerException ex) {               
                control.threadError(ThreadErrors.HUMIGRAFCONNECTIONERROR);
            } catch (Exception ex) {                
                control.threadError(ThreadErrors.WAITERROR);                
            }
        }

    }
}
